@@ -38,6 +38,7 @@ GType mstatus_status_menu_item_get_type (void);
 #define	CONF_DIR		"/home/user/.mstatus/"
 #define CONF_FILE		CONF_DIR"mstatus.conf"
 #define MSTATUS_ICON		"/usr/share/pixmaps/mstatus.png"
+#define MSTATUS_BIG_ICON	"/usr/share/pixmaps/mstatus_big.png"
 #define XML_FILE		"/tmp/ret.xml"
 #define API_KEY			"e428a9d7caf533cbedb8676a2089e949"
 #define URL_BASE		"http://api.ping.fm/v1/"
@@ -53,6 +54,14 @@ gchar *  execute_xpath_expression(const char* filename, const xmlChar* xpathExpr
 int  register_namespaces(xmlXPathContextPtr xpathCtx, const xmlChar* nsList);
 gchar * print_xpath_nodes(xmlNodeSetPtr nodes, char *m);
 void get ( gchar *url , gchar *user_key, gchar *limit, gchar *post_method, gchar *body );
+static gboolean mstatus_wizard(void);
+
+static GtkWidget *sentry;
+static GtkWidget *cnt;
+static GtkWidget *cstatus;
+static guint timeout;
+static GtkWidget *dialog;
+static GtkWidget *update_btn;
 
 /**/
 
